module.exports = defineTest({
	description: 'it does dynamic lookup optimization of internal namespaces for string-literal keys'
});
